pub enum LinuxClipboardKind {
Clipboard,
Primary,
Secondary,
}Expand description
Clipboard selection
Linux has a concept of clipboard “selections” which tend to be used in different contexts. This
enum provides a way to get/set to a specific clipboard (the default
Clipboard being used for the common platform API). You can choose which
clipboard to use with GetExtLinux::clipboard and SetExtLinux::clipboard.
See https://specifications.freedesktop.org/clipboards-spec/clipboards-0.1.txt for a better description of the different clipboards.
Variants
Clipboard
Typically used selection for explicit cut/copy/paste actions (ie. windows/macos like clipboard behavior)
Primary
Typically used for mouse selections and/or currently selected text. Accessible via middle mouse click.
On Wayland, this may not be available for all systems (requires a compositor supporting version 2 or above) and operations using this will return an error if unsupported.
Secondary
The secondary clipboard is rarely used but theoretically available on X11.
On Wayland, this is not be available and operations using this variant will return an error.